package com.hrsk.cloud.eg.infrastructure.business;

import com.alibaba.fastjson2.JSONObject;
import com.google.common.collect.Lists;
import com.hrsk.cloud.eg.constant.BusinessPrefixEnum;
import com.hrsk.cloud.eg.domain.api.HttpApiConfig;
import com.hrsk.cloud.eg.domain.api.KeyValueObject;
import com.hrsk.cloud.eg.domain.api.common.ApiPayloadTypeEnum;
import com.hrsk.cloud.eg.domain.api.common.ValueObjectTypeEnum;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.EgApiDo;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.EgApiEndpointDo;
import com.hrsk.cloud.eg.infrastructure.service.EgApiEndpointService;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author zhangyy
 * @version 1.0
 * @description: GenerateHttpApiConfig 迁移api配置的处理类
 * @date 2024/8/29 17:54
 */
@Slf4j
@Service
public class GenerateCheckIntoHttpApiConfigService {

    @Resource
    private EgApiService egApiService;

    @Resource
    private EgApiEndpointService egApiEndpointService;

    /**
     * @description:  原始惠融对接api转化
     * @param:
     * @return:
     * @author zhangyy
     * @date: 2024/8/29 17:58
     */
    public void  generateHuiRonHuiRonApiConfig(String huiRonApiConfig){
        EgApiDo egApiDo=new EgApiDo();
        egApiDo.setApiCode("EG:"+BusinessPrefixEnum.CHECK_INTO_PREFIX.getCode()+":HUIRONG_CRM:9");
        egApiDo.setApiName(BusinessPrefixEnum.CHECK_INTO_PREFIX.getMsg());
        egApiService.save(egApiDo);
        JSONObject jsonObject = JSONObject.parseObject(huiRonApiConfig);
        EgApiEndpointDo egApiEndpointDo=new EgApiEndpointDo();
        egApiEndpointDo.setApiCode(egApiDo.getApiCode());
        egApiEndpointDo.setApiId(egApiDo.getId());
        egApiEndpointDo.setApiName(jsonObject.getString("name"));
        egApiEndpointDo.setApiConfig(HessianUtils.serialize(createHuiRonCheckIntoBean(huiRonApiConfig)));
        egApiEndpointService.save(egApiEndpointDo);
    }

    /**
     * @description: 对接我们openapiRsa文档转化
     * @param:
     * @return:
     * @author zhangyy
     * @date: 2024/9/4 10:42
     */
    public void  generateOpenApiRSAConfig(String openApiConfig) {
        EgApiDo egApiDo=new EgApiDo();
        egApiDo.setApiCode("EG:"+BusinessPrefixEnum.CHECK_INTO_PREFIX.getCode()+":OPEN_API:1");
        egApiDo.setApiName(BusinessPrefixEnum.CHECK_INTO_PREFIX.getMsg());
        egApiService.save(egApiDo);
        JSONObject jsonObject = JSONObject.parseObject(openApiConfig);
        EgApiEndpointDo egApiEndpointDo=new EgApiEndpointDo();
        egApiEndpointDo.setApiCode(egApiDo.getApiCode());
        egApiEndpointDo.setApiId(egApiDo.getId());
        egApiEndpointDo.setApiName(jsonObject.getString("name"));
        egApiEndpointDo.setApiConfig(HessianUtils.serialize(createOpenApiRsaCheckIntoBean(openApiConfig)));
        egApiEndpointService.save(egApiEndpointDo);
    }

    /**
     * @description: 对接我们openapiAes文档转化
     * @param:
     * @return:
     * @author zhangyy
     * @date: 2024/9/4 10:42
     */
    public void  generateOpenApiAesConfig(String openApiConfig) {
        EgApiDo egApiDo=new EgApiDo();
        egApiDo.setApiCode("EG:"+BusinessPrefixEnum.CHECK_INTO_PREFIX.getCode()+":OPEN_API_AES:13");
        egApiDo.setApiName(BusinessPrefixEnum.CHECK_INTO_PREFIX.getMsg());
        egApiService.save(egApiDo);
        JSONObject jsonObject = JSONObject.parseObject(openApiConfig);
        EgApiEndpointDo egApiEndpointDo=new EgApiEndpointDo();
        egApiEndpointDo.setApiCode(egApiDo.getApiCode());
        egApiEndpointDo.setApiId(egApiDo.getId());
        egApiEndpointDo.setApiName(jsonObject.getString("name"));
        egApiEndpointDo.setApiConfig(HessianUtils.serialize(createOpenApiAesCheckIntoBean(openApiConfig)));
        egApiEndpointService.save(egApiEndpointDo);
    }

    /** 
     * @description: 庆鱼api转化
     * @param:
     * @return:  
     * @author zhangyy
     * @date: 2024/9/4 14:58
     */ 
    public void  generateQinYuConfig(String openApiConfig) {
        EgApiDo egApiDo=new EgApiDo();
        egApiDo.setApiCode("EG:"+BusinessPrefixEnum.CHECK_INTO_PREFIX.getCode()+":CRM_QY:4");
        egApiDo.setApiName(BusinessPrefixEnum.CHECK_INTO_PREFIX.getMsg());
        egApiService.save(egApiDo);
        JSONObject jsonObject = JSONObject.parseObject(openApiConfig);
        EgApiEndpointDo egApiEndpointDo=new EgApiEndpointDo();
        egApiEndpointDo.setApiCode(egApiDo.getApiCode());
        egApiEndpointDo.setApiId(egApiDo.getId());
        egApiEndpointDo.setApiName(jsonObject.getString("name"));
        egApiEndpointDo.setApiConfig(HessianUtils.serialize(createQinYuCheckIntoBean(openApiConfig)));
        egApiEndpointService.save(egApiEndpointDo);
    }

    /**
     * @description: 庆鱼创建api
     * @param:
     * @return:
     * @author zhangyy
     * @date: 2024/9/4 14:58
     */
    private HttpApiConfig createQinYuCheckIntoBean(String openApiConfig) {
       // todo
//        {"url":"https://king.cdsxlc.cn/saasbg","key":"fluxZhudai*_key","tenantId":"1637995763721633794","trafficPlatformId":"1636573781981466625"}
        JSONObject jsonObject=JSONObject.parseObject(openApiConfig);
        HttpApiConfig httpApiConfig = new HttpApiConfig();
        httpApiConfig.setUrl(jsonObject.getString("url")+"/openapi/interface/query/phones");
        httpApiConfig.setMethod("POST");
        httpApiConfig.setContentType(ApiPayloadTypeEnum.APPLICATION_JSON.getCode());
        List<KeyValueObject> headers = Lists.newArrayList();
        KeyValueObject head=new KeyValueObject();
        head.setType(ValueObjectTypeEnum.BASIC.getType());
        head.setKey("Content-Type");
        head.setValue("application/json");
        headers.add(head);
        httpApiConfig.setHeader(headers);
        JSONObject body=new  JSONObject();

        KeyValueObject attackPhone=new KeyValueObject();
        attackPhone.setType("spel");
        attackPhone.setValue("#param.user.phoneMd5");
        KeyValueObject merchantNo=new KeyValueObject();

        merchantNo.setType("spel");
        merchantNo.setValue("#param.user.companyCity");

        body.put("data","#"+JSONObject.toJSONString(attackPhone));
        body.put("sign","#"+JSONObject.toJSONString(merchantNo));
        body.put("trafficPlatformId","#"+JSONObject.toJSONString(merchantNo));
        //主体
        httpApiConfig.setContent(JSONObject.toJSONString(body));
        JSONObject resultObj=new  JSONObject();
        KeyValueObject status=new KeyValueObject();
        status.setType("spel");
        status.setValue("#root[data][status]");
        resultObj.put("status","#"+JSONObject.toJSONString(status));
        httpApiConfig.setResult(JSONObject.toJSONString(resultObj));
        String jsonString = JSONObject.toJSONString(httpApiConfig);
        log.info("qin yu api  {}",jsonString);
        return httpApiConfig;
    }

    /**
     * @description: openapi Rsa 信息
     * @author zhangyy
     * @date 2024/9/4 10:56
     * @version 1.0
     */
    private HttpApiConfig createOpenApiAesCheckIntoBean(String param) {
        JSONObject jsonObject=JSONObject.parseObject(param);
        HttpApiConfig httpApiConfig = new HttpApiConfig();
        httpApiConfig.setUrl(jsonObject.getString("openapiCheckUrl"));
        httpApiConfig.setMethod("POST");
        httpApiConfig.setContentType(ApiPayloadTypeEnum.APPLICATION_JSON.getCode());
        List<KeyValueObject> headers = Lists.newArrayList();
        KeyValueObject head=new KeyValueObject();
        head.setType(ValueObjectTypeEnum.BASIC.getType());
        head.setKey("Content-Type");
        head.setValue("application/json");
        headers.add(head);
        httpApiConfig.setHeader(headers);
        JSONObject body=new  JSONObject();
        KeyValueObject attackPhone=new KeyValueObject();
        attackPhone.setType("spel");
        attackPhone.setValue("#param.user.phoneMd5");
        KeyValueObject merchantNo=new KeyValueObject();
        merchantNo.setType("spel");
        merchantNo.setValue("#param.user.companyCity");
        body.put("phoneMd5","#"+JSONObject.toJSONString(attackPhone));
        body.put("city","#"+JSONObject.toJSONString(merchantNo));
        //主体
        httpApiConfig.setContent(JSONObject.toJSONString(body));
        JSONObject resultObj=new  JSONObject();
        KeyValueObject status=new KeyValueObject();
        status.setType("spel");
        status.setValue("#root[data][status]");
        resultObj.put("status","#"+JSONObject.toJSONString(status));
        httpApiConfig.setResult(JSONObject.toJSONString(resultObj));
        String jsonString = JSONObject.toJSONString(httpApiConfig);
        log.info("open api  rsa{}",jsonString);
        return httpApiConfig;
    }
    /**
     * @description: openapi Rsa 信息
     * @author zhangyy
     * @date 2024/9/4 10:56
     * @version 1.0
     */
    private HttpApiConfig createOpenApiRsaCheckIntoBean(String param) {
        JSONObject jsonObject=JSONObject.parseObject(param);
        HttpApiConfig httpApiConfig = new HttpApiConfig();
        httpApiConfig.setUrl(jsonObject.getString("openapiCheckUrl"));
        httpApiConfig.setMethod("POST");
        httpApiConfig.setContentType(ApiPayloadTypeEnum.APPLICATION_JSON.getCode());
        List<KeyValueObject> headers = Lists.newArrayList();
        KeyValueObject head=new KeyValueObject();
        head.setType(ValueObjectTypeEnum.BASIC.getType());
        head.setKey("Content-Type");
        head.setValue("application/json");
        headers.add(head);
        httpApiConfig.setHeader(headers);
        JSONObject body=new  JSONObject();
        KeyValueObject attackPhone=new KeyValueObject();
        attackPhone.setType("spel");
        attackPhone.setValue("#param.user.phoneMd5");
        KeyValueObject merchantNo=new KeyValueObject();
        merchantNo.setType("spel");
        merchantNo.setValue("#param.user.companyCity");
        body.put("phoneMd5","#"+JSONObject.toJSONString(attackPhone));
        body.put("city","#"+JSONObject.toJSONString(merchantNo));
        //主体
        httpApiConfig.setContent(JSONObject.toJSONString(body));
        JSONObject resultObj=new  JSONObject();
        KeyValueObject status=new KeyValueObject();
        status.setType("spel");
        status.setValue("#root[data][status]");
        resultObj.put("status","#"+JSONObject.toJSONString(status));
        httpApiConfig.setResult(JSONObject.toJSONString(resultObj));
        String jsonString = JSONObject.toJSONString(httpApiConfig);
        log.info("open api  rsa{}",jsonString);
        return httpApiConfig;
    }

    /**
     * @description: 创建撞库httpApi信息
     * @param:
     * @return:
     * @author zhangyy
     * @date: 2024/8/30 09:31
     */
    public HttpApiConfig createHuiRonCheckIntoBean(String param){
        JSONObject jsonObject=JSONObject.parseObject(param);
        HttpApiConfig httpApiConfig = new HttpApiConfig();
        httpApiConfig.setUrl(jsonObject.getString("checkUrl"));
        httpApiConfig.setMethod("POST");
        httpApiConfig.setContentType(ApiPayloadTypeEnum.APPLICATION_JSON.getCode());
        List<KeyValueObject> headers = Lists.newArrayList();
        KeyValueObject head=new KeyValueObject();
        head.setType(ValueObjectTypeEnum.BASIC.getType());
        head.setKey("Content-Type");
        head.setValue("application/json");
        headers.add(head);
        httpApiConfig.setHeader(headers);
        JSONObject body=new  JSONObject();
        KeyValueObject attackPhone=new KeyValueObject();
        attackPhone.setType("spel");
        attackPhone.setValue("#param.user.phoneMd5");
        KeyValueObject merchantNo=new KeyValueObject();
        merchantNo.setType("spel");
        merchantNo.setValue("#param.plan.bid");
        body.put("attackPhone","#"+JSONObject.toJSONString(attackPhone));
        body.put("merchantNo","#"+JSONObject.toJSONString(merchantNo));
        //主体
        httpApiConfig.setContent(JSONObject.toJSONString(body));
        JSONObject resultObj=new  JSONObject();
        KeyValueObject status=new KeyValueObject();
        status.setType("spel");
        status.setValue("#root[data][status]");
        resultObj.put("status","#"+JSONObject.toJSONString(status));
        httpApiConfig.setResult(JSONObject.toJSONString(resultObj));
        String jsonString = JSONObject.toJSONString(httpApiConfig);
        log.info("huiRon api {}",jsonString);
         return httpApiConfig;
    }

}